==> billogram-foundation-2.3.2.tgz: package/modules/components/button/Button.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';


export default ({
    block,
    displayName,
    Spinner
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');
    invariant(Spinner !== undefined, 'Missing Spinner component.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: PropTypes.string,
            loading: PropTypes.bool,
            onClick: PropTypes.func,
            type: PropTypes.oneOf([
                'button',
                'submit'
            ]),
            ui: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.arrayOf(PropTypes.string)
            ])
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                icon: null,
                loading: false,
                onClick: (/* evt */) => {},
                stretched: false,
                type: 'button',
                ui: ''
            };
        },

        render() {
            const { children, disabled, icon, loading, onClick, type, ui } = this.props;
            const iconOnly = !isNullOrEmpty(icon) && children === null;

            return (
                <button
                    type={ type }
                    className={ block({ disabled, 'icon-only': iconOnly, loading }, typeof ui === 'string' ? [ui] : ui) }
                    disabled={ disabled || loading }
                    onClick={ onClick }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                    <div className={ block('spinner') }>
                        <Spinner />
                    </div>
                </button>
            );
        }

    });

};

==> billogram-foundation-2.3.5.tgz: package/modules/components/button/Button.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';


export default ({
    block,
    displayName,
    Spinner
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');
    invariant(Spinner !== undefined, 'Missing Spinner component.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: PropTypes.string,
            loading: PropTypes.bool,
            onClick: PropTypes.func,
            onKeyDown: PropTypes.func,
            onKeyPress: PropTypes.func,
            onKeyUp: PropTypes.func,
            type: PropTypes.oneOf([
                'button',
                'submit'
            ]),
            ui: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.arrayOf(PropTypes.string)
            ])
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                icon: null,
                loading: false,
                onClick: (/* evt */) => {},
                onKeyDown: (/* evt */) => {},
                onKeyPress: (/* evt */) => {},
                onKeyUp: (/* evt */) => {},
                stretched: false,
                type: 'button',
                ui: ''
            };
        },

        render() {
            const { children, disabled, icon, loading, onClick, onKeyDown, onKeyPress, onKeyUp, type, ui } = this.props;
            const iconOnly = !isNullOrEmpty(icon) && children === null;

            return (
                <button
                    type={ type }
                    className={ block({ disabled, 'icon-only': iconOnly, loading }, typeof ui === 'string' ? [ui] : ui) }
                    disabled={ disabled || loading }
                    onClick={ onClick }
                    onKeyDown={ onKeyDown }
                    onKeyPress={ onKeyPress }
                    onKeyUp={ onKeyUp }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                    <div className={ block('spinner') }>
                        <Spinner />
                    </div>
                </button>
            );
        }

    });

};
